@@ -44,7 +44,7 @@ func envCommand(cmd *cobra.Command, args []string) {
 		}
 	}
 
-	for _, env := range lfs.Environ(cfg, getTransferManifest()) {
+	for _, env := range lfs.Environ(cfg, getTransferManifest(), oldEnv) {
 		Print(env)
 	}
 
