@@ -17,7 +17,8 @@ import (
 	"github.com/git-lfs/git-lfs/lfs"
 	"github.com/git-lfs/git-lfs/tasklog"
 	"github.com/git-lfs/git-lfs/tools"
-	"github.com/git-lfs/gitobj"
+	"github.com/git-lfs/git-lfs/tools/humanize"
+	"github.com/git-lfs/gitobj/v2"
 	"github.com/spf13/cobra"
 )
 
@@ -133,6 +134,10 @@ func migrateImportCommand(cmd *cobra.Command, args []string) {
 	gitfilter := lfs.NewGitFilter(cfg)
 
 	var fixups *gitattr.Tree
+	above, err := humanize.ParseBytes(migrateImportAboveFmt)
+	if err != nil {
+		ExitWithError(errors.Wrap(err, "fatal: cannot parse --above=<n>"))
+	}
 
 	migrate(args, rewriter, l, &githistory.RewriteOptions{
 		Verbose:           migrateVerbose,
@@ -141,6 +146,9 @@ func migrateImportCommand(cmd *cobra.Command, args []string) {
 			if filepath.Base(path) == ".gitattributes" {
 				return b, nil
 			}
+			if (above > 0) && (uint64(b.Size) < above) {
+				return b, nil
+			}
 
 			if migrateFixup {
 				var ok bool
@@ -164,6 +172,8 @@ func migrateImportCommand(cmd *cobra.Command, args []string) {
 
 			if ext := filepath.Ext(path); len(ext) > 0 {
 				exts.Add(fmt.Sprintf("*%s filter=lfs diff=lfs merge=lfs -text", ext))
+			} else {
+				exts.Add(fmt.Sprintf("/%s filter=lfs diff=lfs merge=lfs -text", path))
 			}
 
 			return &gitobj.Blob{
@@ -283,7 +293,7 @@ func trackedFromFilter(filter *filepathfilter.Filter) *tools.OrderedSet {
 	}
 
 	for _, exclude := range filter.Exclude() {
-		tracked.Add(fmt.Sprintf("%s text -filter -merge -diff", escapeAttrPattern(exclude)))
+		tracked.Add(fmt.Sprintf("%s !text -filter -merge -diff", escapeAttrPattern(exclude)))
 	}
 
 	return tracked
