@@ -7,7 +7,6 @@ import (
 	"io"
 	"os"
 	"path/filepath"
-	"regexp"
 	"strings"
 
 	"github.com/git-lfs/git-lfs/git"
@@ -22,18 +21,17 @@ var (
 )
 
 func statusCommand(cmd *cobra.Command, args []string) {
-	requireInRepo()
-	requireWorkingCopy()
+	setupWorkingCopy()
 
 	// tolerate errors getting ref so this works before first commit
 	ref, _ := git.CurrentRef()
 
 	scanIndexAt := "HEAD"
 	if ref == nil {
-		scanIndexAt = git.RefBeforeFirstCommit
+		scanIndexAt = git.EmptyTree()
 	}
 
-	scanner, err := lfs.NewPointerScanner(cfg.OSEnv())
+	scanner, err := lfs.NewPointerScanner(cfg.GitEnv(), cfg.OSEnv())
 	if err != nil {
 		ExitWithError(err)
 	}
@@ -58,7 +56,7 @@ func statusCommand(cmd *cobra.Command, args []string) {
 
 	wd = tools.ResolveSymlinks(wd)
 
-	Print("\nGit LFS objects to be committed:\n")
+	Print("\nObjects to be committed:\n")
 	for _, entry := range staged {
 		// Find a path from the current working directory to the
 		// absolute path of each side of the entry.
@@ -73,7 +71,7 @@ func statusCommand(cmd *cobra.Command, args []string) {
 		}
 	}
 
-	Print("\nGit LFS objects not staged for commit:\n")
+	Print("\nObjects not staged for commit:\n")
 	for _, entry := range unstaged {
 		src := relativize(wd, filepath.Join(repo, entry.SrcName))
 
@@ -87,8 +85,6 @@ func statusCommand(cmd *cobra.Command, args []string) {
 	}
 }
 
-var z40 = regexp.MustCompile(`\^?0{40}`)
-
 func formatBlobInfo(s *lfs.PointerScanner, entry *lfs.DiffIndexEntry) string {
 	fromSha, fromSrc, err := blobInfoFrom(s, entry)
 	if err != nil {
@@ -111,7 +107,7 @@ func formatBlobInfo(s *lfs.PointerScanner, entry *lfs.DiffIndexEntry) string {
 
 func blobInfoFrom(s *lfs.PointerScanner, entry *lfs.DiffIndexEntry) (sha, from string, err error) {
 	var blobSha string = entry.SrcSha
-	if z40.MatchString(blobSha) {
+	if git.IsZeroObjectID(blobSha) {
 		blobSha = entry.DstSha
 	}
 
@@ -128,7 +124,7 @@ func blobInfoTo(s *lfs.PointerScanner, entry *lfs.DiffIndexEntry) (sha, from str
 }
 
 func blobInfo(s *lfs.PointerScanner, blobSha, name string) (sha, from string, err error) {
-	if !z40.MatchString(blobSha) {
+	if !git.IsZeroObjectID(blobSha) {
 		s.Scan(blobSha)
 		if err := s.Err(); err != nil {
 			if git.IsMissingObject(err) {
@@ -170,12 +166,12 @@ func blobInfo(s *lfs.PointerScanner, blobSha, name string) (sha, from string, er
 }
 
 func scanIndex(ref string) (staged, unstaged []*lfs.DiffIndexEntry, err error) {
-	uncached, err := lfs.NewDiffIndexScanner(ref, false)
+	uncached, err := lfs.NewDiffIndexScanner(ref, false, true)
 	if err != nil {
 		return nil, nil, err
 	}
 
-	cached, err := lfs.NewDiffIndexScanner(ref, true)
+	cached, err := lfs.NewDiffIndexScanner(ref, true, false)
 	if err != nil {
 		return nil, nil, err
 	}
@@ -246,7 +242,7 @@ func statusScanRefRange(ref *git.Ref) {
 	})
 	defer gitscanner.Close()
 
-	Print("Git LFS objects to be pushed to %s:\n", remoteRef.Name)
+	Print("Objects to be pushed to %s:\n", remoteRef.Name)
 	if err := gitscanner.ScanRefRange(ref.Sha, remoteRef.Sha, nil); err != nil {
 		Panic(err, "Could not scan for Git LFS objects")
 	}
