@@ -76,7 +76,7 @@ func NewIn(workdir, gitdir string) *Configuration {
 
 	c.Git = &delayedEnvironment{
 		callback: func() Environment {
-			sources, err := gitConf.Sources(filepath.Join(c.LocalWorkingDir(), ".lfsconfig"))
+			sources, err := gitConf.Sources(c.LocalWorkingDir(), ".lfsconfig")
 			if err != nil {
 				fmt.Fprintf(os.Stderr, "Error reading git config: %s\n", err)
 			}
@@ -139,7 +139,7 @@ type Values struct {
 }
 
 // NewFrom returns a new `*config.Configuration` that reads both its Git
-// and Enviornment-level values from the ones provided instead of the actual
+// and Environment-level values from the ones provided instead of the actual
 // `.gitconfig` file or `os.Getenv`, respectively.
 //
 // This method should only be used during testing.
@@ -230,12 +230,7 @@ func (c *Configuration) Remote() string {
 	defer c.loading.Unlock()
 
 	if c.currentRemote == nil {
-		if len(ref.Name) == 0 {
-			c.currentRemote = &defaultRemote
-			return defaultRemote
-		}
-
-		if remote, ok := c.Git.Get(fmt.Sprintf("branch.%s.remote", ref.Name)); ok {
+		if remote, ok := c.Git.Get(fmt.Sprintf("branch.%s.remote", ref.Name)); len(ref.Name) != 0 && ok {
 			// try tracking remote
 			c.currentRemote = &remote
 		} else if remotes := c.Remotes(); len(remotes) == 1 {
@@ -273,7 +268,10 @@ func (c *Configuration) PushRemote() string {
 
 func (c *Configuration) SetValidRemote(name string) error {
 	if err := git.ValidateRemote(name); err != nil {
-		return err
+		name := git.RewriteLocalPathAsURL(name)
+		if err := git.ValidateRemote(name); err != nil {
+			return err
+		}
 	}
 	c.SetRemote(name)
 	return nil
@@ -281,7 +279,10 @@ func (c *Configuration) SetValidRemote(name string) error {
 
 func (c *Configuration) SetValidPushRemote(name string) error {
 	if err := git.ValidateRemote(name); err != nil {
-		return err
+		name := git.RewriteLocalPathAsURL(name)
+		if err := git.ValidateRemote(name); err != nil {
+			return err
+		}
 	}
 	c.SetPushRemote(name)
 	return nil
@@ -329,7 +330,14 @@ func (c *Configuration) HookDir() (string, error) {
 	if git.IsGitVersionAtLeast("2.9.0") {
 		hp, ok := c.Git.Get("core.hooksPath")
 		if ok {
-			return tools.ExpandPath(hp, false)
+			path, err := tools.ExpandPath(hp, false)
+			if err != nil {
+				return "", err
+			}
+			if filepath.IsAbs(path) {
+				return path, nil
+			}
+			return filepath.Join(c.LocalWorkingDir(), path), nil
 		}
 	}
 	return filepath.Join(c.LocalGitStorageDir(), "hooks"), nil
@@ -454,6 +462,10 @@ func (c *Configuration) FindGitLocalKey(key string) string {
 	return c.gitConfig.FindLocal(key)
 }
 
+func (c *Configuration) FindGitWorktreeKey(key string) string {
+	return c.gitConfig.FindWorktree(key)
+}
+
 func (c *Configuration) SetGitGlobalKey(key, val string) (string, error) {
 	return c.gitConfig.SetGlobal(key, val)
 }
@@ -466,6 +478,10 @@ func (c *Configuration) SetGitLocalKey(key, val string) (string, error) {
 	return c.gitConfig.SetLocal(key, val)
 }
 
+func (c *Configuration) SetGitWorktreeKey(key, val string) (string, error) {
+	return c.gitConfig.SetWorktree(key, val)
+}
+
 func (c *Configuration) UnsetGitGlobalSection(key string) (string, error) {
 	return c.gitConfig.UnsetGlobalSection(key)
 }
@@ -478,6 +494,10 @@ func (c *Configuration) UnsetGitLocalSection(key string) (string, error) {
 	return c.gitConfig.UnsetLocalSection(key)
 }
 
+func (c *Configuration) UnsetGitWorktreeSection(key string) (string, error) {
+	return c.gitConfig.UnsetWorktreeSection(key)
+}
+
 func (c *Configuration) UnsetGitLocalKey(key string) (string, error) {
 	return c.gitConfig.UnsetLocalKey(key)
 }
