@@ -2,6 +2,7 @@ package git
 
 import (
 	"errors"
+	"fmt"
 	"os"
 	"path/filepath"
 	"strings"
@@ -65,7 +66,7 @@ func (c *Configuration) Find(val string) string {
 	return output
 }
 
-// FindGlobal returns the git config value global scope for the key
+// FindGlobal returns the git config value in global scope for the key
 func (c *Configuration) FindGlobal(key string) string {
 	output, _ := c.gitConfig("--global", key)
 	return output
@@ -77,12 +78,18 @@ func (c *Configuration) FindSystem(key string) string {
 	return output
 }
 
-// Find returns the git config value for the key
+// FindLocal returns the git config value in local scope for the key
 func (c *Configuration) FindLocal(key string) string {
 	output, _ := c.gitConfig("--local", key)
 	return output
 }
 
+// FindWorktree returns the git config value in worktree or local scope for the key, depending on whether multiple worktrees are in use
+func (c *Configuration) FindWorktree(key string) string {
+	output, _ := c.gitConfig("--worktree", key)
+	return output
+}
+
 // SetGlobal sets the git config value for the key in the global config
 func (c *Configuration) SetGlobal(key, val string) (string, error) {
 	return c.gitConfigWrite("--global", "--replace-all", key, val)
@@ -93,6 +100,16 @@ func (c *Configuration) SetSystem(key, val string) (string, error) {
 	return c.gitConfigWrite("--system", "--replace-all", key, val)
 }
 
+// SetLocal sets the git config value for the key in the specified config file
+func (c *Configuration) SetLocal(key, val string) (string, error) {
+	return c.gitConfigWrite("--replace-all", key, val)
+}
+
+// SetWorktree sets the git config value for the key in the worktree or local config, depending on whether multiple worktrees are in use
+func (c *Configuration) SetWorktree(key, val string) (string, error) {
+	return c.gitConfigWrite("--worktree", "--replace-all", key, val)
+}
+
 // UnsetGlobalSection removes the entire named section from the global config
 func (c *Configuration) UnsetGlobalSection(key string) (string, error) {
 	return c.gitConfigWrite("--global", "--remove-section", key)
@@ -103,14 +120,14 @@ func (c *Configuration) UnsetSystemSection(key string) (string, error) {
 	return c.gitConfigWrite("--system", "--remove-section", key)
 }
 
-// UnsetLocalSection removes the entire named section from the system config
+// UnsetLocalSection removes the entire named section from the local config
 func (c *Configuration) UnsetLocalSection(key string) (string, error) {
 	return c.gitConfigWrite("--local", "--remove-section", key)
 }
 
-// SetLocal sets the git config value for the key in the specified config file
-func (c *Configuration) SetLocal(key, val string) (string, error) {
-	return c.gitConfigWrite("--replace-all", key, val)
+// UnsetWorktreeSection removes the entire named section from the worktree or local config, depending on whether multiple worktrees are in use
+func (c *Configuration) UnsetWorktreeSection(key string) (string, error) {
+	return c.gitConfigWrite("--worktree", "--remove-section", key)
 }
 
 // UnsetLocalKey removes the git config value for the key from the specified config file
@@ -118,17 +135,33 @@ func (c *Configuration) UnsetLocalKey(key string) (string, error) {
 	return c.gitConfigWrite("--unset", key)
 }
 
-func (c *Configuration) Sources(optionalFilename string) ([]*ConfigurationSource, error) {
+func (c *Configuration) Sources(dir string, optionalFilename string) ([]*ConfigurationSource, error) {
 	gitconfig, err := c.Source()
 	if err != nil {
 		return nil, err
 	}
 
-	fileconfig, err := c.FileSource(optionalFilename)
-	if err != nil && !os.IsNotExist(err) {
+	bare, err := IsBare()
+	if err != nil {
 		return nil, err
 	}
 
+	// First try to read from the working directory and then the index if
+	// the file is missing from the working directory.
+	var fileconfig *ConfigurationSource
+	if !bare {
+		fileconfig, err = c.FileSource(filepath.Join(dir, optionalFilename))
+		if err != nil {
+			if !os.IsNotExist(err) {
+				return nil, err
+			}
+			fileconfig, _ = c.RevisionSource(fmt.Sprintf(":%s", optionalFilename))
+		}
+	}
+	if fileconfig == nil {
+		fileconfig, _ = c.RevisionSource(fmt.Sprintf("HEAD:%s", optionalFilename))
+	}
+
 	configs := make([]*ConfigurationSource, 0, 2)
 	if fileconfig != nil {
 		configs = append(configs, fileconfig)
@@ -149,6 +182,14 @@ func (c *Configuration) FileSource(filename string) (*ConfigurationSource, error
 	return ParseConfigLines(out, true), nil
 }
 
+func (c *Configuration) RevisionSource(revision string) (*ConfigurationSource, error) {
+	out, err := c.gitConfig("-l", "--blob", revision)
+	if err != nil {
+		return nil, err
+	}
+	return ParseConfigLines(out, true), nil
+}
+
 func (c *Configuration) Source() (*ConfigurationSource, error) {
 	out, err := c.gitConfig("-l")
 	if err != nil {
@@ -159,7 +200,6 @@ func (c *Configuration) Source() (*ConfigurationSource, error) {
 
 func (c *Configuration) gitConfig(args ...string) (string, error) {
 	args = append([]string{"config"}, args...)
-	subprocess.Trace("git", args...)
 	cmd := subprocess.ExecCommand("git", args...)
 	if len(c.GitDir) > 0 {
 		cmd.Dir = c.GitDir
