@@ -5,6 +5,7 @@ import (
 	"net/http"
 
 	"github.com/git-lfs/git-lfs/config"
+	"github.com/git-lfs/git-lfs/creds"
 	"github.com/git-lfs/git-lfs/lfshttp"
 )
 
@@ -25,6 +26,10 @@ func (c *Client) do(req *http.Request, remote string, via []*http.Request) (*htt
 	return c.client.Do(req)
 }
 
+func (c *Client) doWithAccess(req *http.Request, remote string, via []*http.Request, mode creds.AccessMode) (*http.Response, error) {
+	return c.client.DoWithAccess(req, mode)
+}
+
 func (c *Client) LogRequest(r *http.Request, reqKey string) *http.Request {
 	return c.client.LogRequest(r, reqKey)
 }
