@@ -9,7 +9,7 @@ import (
 // ExecCommand is a small platform specific wrapper around os/exec.Command
 func ExecCommand(name string, arg ...string) *Cmd {
 	cmd := exec.Command(name, arg...)
-	cmd.Env = env
 	cmd.Path, _ = LookPath(name)
+	cmd.Env = fetchEnvironment()
 	return newCmd(cmd)
 }
