@@ -12,6 +12,6 @@ func ExecCommand(name string, arg ...string) *Cmd {
 	cmd := exec.Command(name, arg...)
 	cmd.Path, _ = LookPath(name)
 	cmd.SysProcAttr = &syscall.SysProcAttr{HideWindow: true}
-	cmd.Env = env
+	cmd.Env = fetchEnvironment()
 	return newCmd(cmd)
 }
