@@ -23,7 +23,7 @@ begin_test "attempt private access without credential helper"
   git config credential.helper lfsnoop
   git config -l
 
-  GIT_TERMINAL_PROMPT=0 git push origin master 2>&1 | tee push.log
+  GIT_TERMINAL_PROMPT=0 git push origin main 2>&1 | tee push.log
   grep "Authorization error: $GITSERVER/$reponame" push.log ||
     grep "Git credentials for $GITSERVER/$reponame not found" push.log
 )
@@ -44,7 +44,7 @@ begin_test "askpass: push with bad askpass"
   git commit -m "initial commit"
 
   git config "credential.helper" ""
-  GIT_TERMINAL_PROMPT=0 GIT_ASKPASS="lfs-askpass-2" SSH_ASKPASS="dont-call-me" GIT_TRACE=1 git push origin master 2>&1 | tee push.log
+  GIT_TERMINAL_PROMPT=0 GIT_ASKPASS="lfs-askpass-2" SSH_ASKPASS="dont-call-me" GIT_TRACE=1 git push origin main 2>&1 | tee push.log
   grep "filling with GIT_ASKPASS" push.log                     # attempt askpass
   grep 'credential fill error: exec: "lfs-askpass-2"' push.log # askpass fails
   grep "creds: git credential fill" push.log                   # attempt git credential
