@@ -132,11 +132,11 @@ func (a *customAdapter) WorkerStarting(workerNum int) (interface{}, error) {
 	cmd := subprocess.ExecCommand(cmdName, cmdArgs...)
 	outp, err := cmd.StdoutPipe()
 	if err != nil {
-		return nil, fmt.Errorf("Failed to get stdout for custom transfer command %q remote: %v", a.path, err)
+		return nil, fmt.Errorf("failed to get stdout for custom transfer command %q remote: %v", a.path, err)
 	}
 	inp, err := cmd.StdinPipe()
 	if err != nil {
-		return nil, fmt.Errorf("Failed to get stdin for custom transfer command %q remote: %v", a.path, err)
+		return nil, fmt.Errorf("failed to get stdin for custom transfer command %q remote: %v", a.path, err)
 	}
 	// Capture stderr to trace
 	tracer := &traceWriter{}
@@ -144,7 +144,7 @@ func (a *customAdapter) WorkerStarting(workerNum int) (interface{}, error) {
 	cmd.Stderr = tracer
 	err = cmd.Start()
 	if err != nil {
-		return nil, fmt.Errorf("Failed to start custom transfer command %q remote: %v", a.path, err)
+		return nil, fmt.Errorf("failed to start custom transfer command %q remote: %v", a.path, err)
 	}
 	// Set up buffered reader/writer since we operate on lines
 	ctx := &customAdapterWorkerContext{workerNum, cmd, outp, bufio.NewReader(outp), inp, tracer}
@@ -160,7 +160,7 @@ func (a *customAdapter) WorkerStarting(workerNum int) (interface{}, error) {
 	}
 	if resp.Error != nil {
 		a.abortWorkerProcess(ctx)
-		return nil, fmt.Errorf("Error initializing custom adapter %q worker %d: %v", a.name, workerNum, resp.Error)
+		return nil, fmt.Errorf("error initializing custom adapter %q worker %d: %v", a.name, workerNum, resp.Error)
 	}
 
 	a.Trace("xfer: started custom adapter process %q for worker %d OK", a.path, workerNum)
@@ -232,7 +232,7 @@ func (a *customAdapter) shutdownWorkerProcess(ctx *customAdapterWorkerContext) e
 	case err := <-finishChan:
 		return err
 	case <-time.After(30 * time.Second):
-		return fmt.Errorf("Timeout while shutting down worker process %d", ctx.workerNum)
+		return fmt.Errorf("timeout while shutting down worker process %d", ctx.workerNum)
 	}
 }
 
@@ -259,12 +259,12 @@ func (a *customAdapter) WorkerEnding(workerNum int, ctx interface{}) {
 
 func (a *customAdapter) DoTransfer(ctx interface{}, t *Transfer, cb ProgressCallback, authOkFunc func()) error {
 	if ctx == nil {
-		return fmt.Errorf("Custom transfer %q was not properly initialized, see previous errors", a.name)
+		return fmt.Errorf("custom transfer %q was not properly initialized, see previous errors", a.name)
 	}
 
 	customCtx, ok := ctx.(*customAdapterWorkerContext)
 	if !ok {
-		return fmt.Errorf("Context object for custom transfer %q was of the wrong type", a.name)
+		return fmt.Errorf("context object for custom transfer %q was of the wrong type", a.name)
 	}
 	var authCalled bool
 
@@ -297,7 +297,7 @@ func (a *customAdapter) DoTransfer(ctx interface{}, t *Transfer, cb ProgressCall
 		case "progress":
 			// Progress
 			if resp.Oid != t.Oid {
-				return fmt.Errorf("Unexpected oid %q in response, expecting %q", resp.Oid, t.Oid)
+				return fmt.Errorf("unexpected oid %q in response, expecting %q", resp.Oid, t.Oid)
 			}
 			if cb != nil {
 				cb(t.Name, t.Size, resp.BytesSoFar, resp.BytesSinceLast)
@@ -306,19 +306,19 @@ func (a *customAdapter) DoTransfer(ctx interface{}, t *Transfer, cb ProgressCall
 		case "complete":
 			// Download/Upload complete
 			if resp.Oid != t.Oid {
-				return fmt.Errorf("Unexpected oid %q in response, expecting %q", resp.Oid, t.Oid)
+				return fmt.Errorf("unexpected oid %q in response, expecting %q", resp.Oid, t.Oid)
 			}
 			if resp.Error != nil {
-				return fmt.Errorf("Error transferring %q: %v", t.Oid, resp.Error)
+				return fmt.Errorf("error transferring %q: %v", t.Oid, resp.Error)
 			}
 			if a.direction == Download {
 				// So we don't have to blindly trust external providers, check SHA
 				if err = tools.VerifyFileHash(t.Oid, resp.Path); err != nil {
-					return fmt.Errorf("Downloaded file failed checks: %v", err)
+					return fmt.Errorf("downloaded file failed checks: %v", err)
 				}
 				// Move file to final location
 				if err = tools.RenameFileCopyPermissions(resp.Path, t.Path); err != nil {
-					return fmt.Errorf("Failed to copy downloaded file: %v", err)
+					return fmt.Errorf("failed to copy downloaded file: %v", err)
 				}
 			} else if a.direction == Upload {
 				if err = verifyUpload(a.apiClient, a.remote, t); err != nil {
@@ -328,7 +328,7 @@ func (a *customAdapter) DoTransfer(ctx interface{}, t *Transfer, cb ProgressCall
 			wasAuthOk = true
 			complete = true
 		default:
-			return fmt.Errorf("Invalid message %q from custom adapter %q", resp.Event, a.name)
+			return fmt.Errorf("invalid message %q from custom adapter %q", resp.Event, a.name)
 		}
 		// Fall through from both progress and completion messages
 		// Call auth on first progress or success to free up other workers
